/*
    jdkdrum, a simple linux command line drum machine
    Copyright (C) 1998  J.D. Koftinoff Software, Ltd. 
    http://www.jdkoftinoff.com/

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/


#ifndef _JDKDRUM_H
#define _JDKDRUN_H

#include <stdio.h>
#include <stdlib.h>
#include <sys/types.h>
#include <fcntl.h>
#include <unistd.h>
#include <sys/mman.h>
#include <pthread.h>
#include <sys/ioctl.h>
#include <linux/soundcard.h>
#include <signal.h>

#define AUDIO_DEVICE "/dev/dsp"
#define SAMPLE_RATE (44100)

int open_audio( void );
void close_audio(void);
int write_audio( signed short *buf, int num_samples );
void *repeat_play_thread(void *);
pthread_t start_repeat_play_thread(void);
int merge_buffer( 
  signed short *audiobuf,
  int repeatpos,
  signed short *buf,
  int buflen,
  int pos, 
  float vol, 
  float pan
  );

int merge_read_file( 
  signed short *audiobuf,
  int repeatpos,
  const char *fname, 
  int pos, 
  float vol, 
  float pan
  );

int merge_echo_read_file( 
  signed short *audiobuf,
  int repeatpos,
  const char *fname, 
  int pos, 
  float vol, 
  float pan,
  int echo_left_time,
  int echo_right_time,
  float echo_left_volume,
  float echo_right_volume
  );
signed short * load_instrument( 
  const char *fname, 
  int *len 
  );
int merge_text_pattern(
  signed short *audiobuf,
  int repeatpos,
  const char *fname,
  int step_position[16],
  const char *pattern
  );
int merge_multi_pattern(
  FILE *in
  );

extern long audiobuf_size;
extern volatile int audiobuf_current_playing;
extern long audiobuf_repeatpos[2];
extern signed short *audiobuf[2];
extern volatile int keep_playing;
extern volatile int play_count;

extern int audio_block_size;
extern int audio_fd;


#endif
